The matrix of orthogonal atomic orbital coefficients (https://chemrxiv.org/engage/chemrxiv/article-details/64160d85aad2a62ca1f937f6) was generated with the help of these several different functions.
For more info please check: 
[CCC GITHUB](https://github.com/hits-ccc/MAOC)
